==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/antistring/translations/antistring_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Konuşma</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Antistring açık</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Mesaj engelle</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Günlük</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Dosyaya günlük yaz</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Koşullar</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Antistring uyarıları</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATA AND TIME      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Koşul</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Kullanma</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Etken</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Değiştir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Konuştuğunuz kişi size aşk mektubu gönderdi</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/antistring/translations/antistring_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Konuşma</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Antistring açık</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Mesaj engelle</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Günlük</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Dosyaya günlük yaz</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Koşullar</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Antistring uyarıları</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Koşul</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Kullanma</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Etken</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Değiştir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>AntistringMessageFilter</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATA AND TIME      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringNotificationService</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Konuştuğunuz kişi size aşk mektubu gönderdi</translation>
    </message>
</context>
</TS>
